﻿// ==========================================================================================================
//  
//   File ID: Testworks 3 - WR.Testworks3.GraphicsManager - ButtonGroupViewModel.cs 
//  
//   Copyright 2011-2016
//   WR Medical Electronics Company
//  
//   Last Changed By: cdo - Collin D. O'Connor
//   Last Changed Date: 3:38 PM, 06/01/2016
//   Created Date: 12:22 PM, 11/06/2013
//  
//   Notes:
//   
// ==========================================================================================================

namespace WR.Testworks3.GraphicsManager.ViewModels {
    #region Imported Namespaces

    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using Models;
    using ViewModelFramework;

    #endregion

    ///============================================================================================
    /// <summary>   Button group view model. </summary>
    ///
    /// <remarks>   Cdo, 7/19/2011. </remarks>
    ///
    /// <seealso cref="T:WR.Testworks3.ViewModelFramework.BaseDomainObjectViewModel{WR.Testworks3.GraphicsManager.Models.IButtonGroup}"/>
    /// <seealso cref="T:WR.Testworks3.GraphicsManager.ViewModels.IButtonGroupViewModel"/>
    ///============================================================================================
    public class ButtonGroupViewModel : BaseDomainObjectViewModel<IButtonGroup>, IButtonGroupViewModel {
        #region Implementation of IButtonGroupViewModel

        /// <summary>   The name. </summary>
        private string _name;

        /// <summary>   The description. </summary>
        private string _description;

        /// <summary>   The button view models. </summary>
        private ObservableCollection<IButtonViewModel> _buttonViewModels;

        ///========================================================================================
        /// <summary>   Constructor. </summary>
        ///
        /// <remarks>   Cdo, 7/19/2011. </remarks>
        ///
        /// <param name="domainObject">     The domain object. </param>
        /// <param name="name">             The name. </param>
        /// <param name="description">      The description. </param>
        /// <param name="buttonViewModels"> The button view models. </param>
        ///========================================================================================
        public ButtonGroupViewModel( IButtonGroup domainObject, string name, string description, IEnumerable<IButtonViewModel> buttonViewModels )
            : base( domainObject ) {
            this._name = name;
            this._description = description;
            this._buttonViewModels = new ObservableCollection<IButtonViewModel>( buttonViewModels );
        }

        ///========================================================================================
        /// <summary>   Gets or sets the name. </summary>
        ///
        /// <value> The name. </value>
        ///
        /// <seealso cref="P:WR.Testworks3.GraphicsManager.ViewModels.IButtonGroupViewModel.Name"/>
        ///========================================================================================
        public string Name
        {
            get { return this._name; }
            set
            {
                this._name = value;
                this.OnPropertyChanged( );
            }
        }

        ///========================================================================================
        /// <summary>   Gets or sets the description. </summary>
        ///
        /// <value> The description. </value>
        ///
        /// <seealso cref="P:WR.Testworks3.GraphicsManager.ViewModels.IButtonGroupViewModel.Description"/>
        ///========================================================================================
        public string Description
        {
            get { return this._description; }
            set
            {
                this._description = value;
                this.OnPropertyChanged( );
            }
        }

        ///========================================================================================
        /// <summary>   Gets or sets the button view models. </summary>
        ///
        /// <value> The button view models. </value>
        ///
        /// <seealso cref="P:WR.Testworks3.GraphicsManager.ViewModels.IButtonGroupViewModel.ButtonViewModels"/>
        ///========================================================================================
        public ObservableCollection<IButtonViewModel> ButtonViewModels
        {
            get { return this._buttonViewModels; }
            set
            {
                this._buttonViewModels = value;
                this.OnPropertyChanged( );
            }
        }

        #endregion
    }
}
