﻿namespace QuickAccess.ViewModelFramework {
    #region Imported Namespaces

    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Diagnostics;
    using System.Runtime.CompilerServices;

    #endregion

    public class BaseViewModel : IBaseViewModel {
        protected string _displayName;

        #region Constructor

        protected BaseViewModel( ) {
            this.ThrowOnInvalidPropertyName = true;
        }

        #endregion 

        #region DisplayName

        public virtual string DisplayName
        {
            get { return this._displayName; }
            protected set { this.SetPropertyAndNotify( ref this._displayName, value, "DisplayName" ); }
        }

        public bool Disposed { get; private set; }

        #endregion 

        #region Debugging Aides

        public void VerifyPropertyName( string propertyName ) {
            if ( TypeDescriptor.GetProperties( this )[ propertyName ] != null )
                return;
            var msg = string.Format( "Invalid property name {0}", propertyName );

            if ( this.ThrowOnInvalidPropertyName ) { throw new Exception( msg ); }
        }

        protected bool ThrowOnInvalidPropertyName { get; set; }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged( [CallerMemberName] string propertyName = null ) {
            this.VerifyPropertyName( propertyName );

            var handler = this.PropertyChanged;
            if ( handler == null )
                return;
            var e = new PropertyChangedEventArgs( propertyName );
            handler( this, e );
        }

        protected virtual bool SetPropertyAndNotify<TFieldType>( ref TFieldType field, TFieldType value, string propertyName ) {
            if ( !( value is bool ) &&
                 EqualityComparer<TFieldType>.Default.Equals( field, value ) ) { return false; }
            field = value;

            this.OnPropertyChanged( propertyName );
            return true;
        }

        #endregion 

        #region IDisposable Members

        public void Dispose( ) {
            if ( this.Disposed ) { return; }
            this.OnDispose( true );
            GC.SuppressFinalize( this );
            this.Disposed = true;
        }

        protected virtual void OnDispose( bool onDispose ) {
            if ( onDispose ) {
            }
        }

#if DEBUG

        ~BaseViewModel( ) {
            this.OnDispose( false );
        }
#endif

        #endregion 
    }
}
