namespace QuickAccess.ViewModelFramework {
    #region Imported Namespaces

    using System;
    using System.Collections.Generic;
    using System.ComponentModel;

    #endregion

    public class BaseDomainObjectViewModel<TDomainObject> : BaseViewModel,
        IBaseDomainObjectViewModel<TDomainObject>,
        IEquatable<BaseDomainObjectViewModel<TDomainObject>> {

        protected IList<string> _dirtyFields;

        protected TDomainObject _domainObject;

        protected IList<string> _loadedFields;

        private bool _isDirty;

        #region Constructors

        public BaseDomainObjectViewModel( TDomainObject domainObject ) {
            this._domainObject = domainObject;
            this._loadedFields = new List<string>( );
            this._dirtyFields = new List<string>( );
            this.IsDirty = false;
        }

        #endregion

        #region IBaseDomainObjectViewModel<TDomainObject> Members

        public bool IsDirty { get { return this._isDirty; } set { this._isDirty = value; } }

        #endregion

        public override int GetHashCode( ) {
            unchecked {
                var hashCode = this._dirtyFields != null ? this._dirtyFields.GetHashCode( ) : 0;
                hashCode = ( hashCode * 397 ) ^ EqualityComparer<TDomainObject>.Default.GetHashCode( this._domainObject );
                hashCode = ( hashCode * 397 ) ^ ( this._loadedFields != null ? this._loadedFields.GetHashCode( ) : 0 );

                return hashCode;
            }
        }

        #region Overrides of BaseViewModel

        protected override bool SetPropertyAndNotify<TFieldType>( ref TFieldType field, TFieldType value, string propertyName ) {
            if ( !base.SetPropertyAndNotify( ref field, value, propertyName ) )
                return false;
            if ( this._dirtyFields.Contains( propertyName ) )
                return true;
            this._loadedFields.Add( propertyName );
            this._dirtyFields.Add( propertyName );
            this.IsDirty = true;
            return true;
        }

        #endregion

        #region Implementation of IBaseDomainObjectViewModel<TDomainObject>

        public TDomainObject DomainObject
        {
            get { return this._domainObject; }
            set
            {
                this._domainObject = value;
                this.OnPropertyChanged( );
            }
        }

        public virtual void Commit( ) {}

        #endregion

        #region Equality members

        public bool Equals( BaseDomainObjectViewModel<TDomainObject> other ) {
            if ( ReferenceEquals( null, other ) ) { return false; }
            if ( ReferenceEquals( this, other ) ) { return true; }
            var equals = EqualityComparer<TDomainObject>.Default.Equals( this._domainObject, other._domainObject ) && ( this.IsDirty == other.IsDirty );
            return equals;
        }

        public override bool Equals( object obj ) {
            if ( ReferenceEquals( null, obj ) ) { return false; }
            if ( ReferenceEquals( this, obj ) ) { return true; }
            var other = obj as BaseDomainObjectViewModel<TDomainObject>;
            var equals = ( other != null ) && this.Equals( other );
            return equals;
        }

        public static bool operator ==( BaseDomainObjectViewModel<TDomainObject> left, BaseDomainObjectViewModel<TDomainObject> right ) {
            return Equals( left, right );
        }

        public static bool operator !=( BaseDomainObjectViewModel<TDomainObject> left, BaseDomainObjectViewModel<TDomainObject> right ) {
            return !Equals( left, right );
        }

        #endregion

        #region Protected Methods

        protected TFieldType IfNullOrEmpty<TFieldType>( ref TFieldType localObject, TFieldType domainObject, string propertyName ) {
            if ( this._loadedFields.Contains( propertyName ) )
                return localObject;
            this._loadedFields.Add( propertyName );
            localObject = domainObject;

            return localObject;
        }

        public void ResetFields( ) {
            this._loadedFields.Clear( );
            this._dirtyFields.Clear( );
            this.IsDirty = false;
        }

        #endregion
    }
}
